# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['qre']
setup_kwargs = {
    'name': 'qre',
    'version': '22.10.1',
    'description': 'Like re, but cuter.',
    'long_description': '# qre - like re, but cuter\n\n[![PyPI - Version](https://img.shields.io/pypi/v/qre)](https://pypi.org/project/qre/)\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)\n[![tests](https://github.com/mikaelho/qre/actions/workflows/tests.yml/badge.svg?branch=main)](https://github.com/mikaelho/qre/actions/workflows/tests.yml)\n\n| Samples |                                                                                 |\n|---------|:--------------------------------------------------------------------------------|\n| Pattern | `"* pattern"`                                                                   |\n| Input   | `"First pattern"`                                                               |\n| Result  | 👍🏼                                                                            |\n|         |                                                                                 |\n| Pattern | `"World\'s [] pattern"`                                                          |\n| Input   | `"World\'s coolest pattern"`                                                     |\n| Result  | `["coolest"]`                                                                   |\n|         |                                                                                 |\n| Pattern | `"product id: [product_id], units: [units: int], price: [unit_price: decimal]"` |\n| Input   | `"Product ID: A123, Units: 3, Price: 1.23"` (case-insensitive)                  |\n| Result  | `{"product_id": "A123", "units": 3, "unit_price": Decimal("1.23")}`             |\n\nThis package owes everything, including most of the codebase, to Thomas Feldtmann\'s\n[simplematch](https://github.com/tfeldmann/simplematch). All poor design decisions are mine.\nSee [this collection](https://github.com/mikaelho/python-human-regex) for other alternatives.\n\n_Status_: Comprehensively tested but never used for anything real. All evolution is expected to be\nincremental.\n\n## Quick start\n\n`pip install qre`\n\nMy first little match:\n\n```python\nimport qre\n\nassert qre.search("in [place]", "Match made in heaven") == {"place": "heaven"}\n```\n\n`qre` is mostly focused on collecting named groups from the input strings, so the return value is\nan easy-to-access dict. Groups are denoted with brackets, which means that patterns are friendly\nwith f-strings.\n\nFor unnamed groups the returned object has been tweaked a little bit - they can be found as a list\nin the `unnamed` attribute:\n\n```python\nassert qre.match("[] [:int]", "Lesson 1").unnamed == ["Lesson", 1]\n```\n\nType specifiers can be used with both named and unnamed groups. They act both as specs for the\npattern to find and, when applicable, as converters to the right type.\n\nCurrently available types are:\n- `int`\n- `float`\n- `decimal`\n- `date` (ISO)\n- `datetime` (ISO)\n- `uuid`\n- `letters`\n- `identifier` (`letters` plus numbers and underscore)\n- `email`\n- `url`\n- `ipv4`\n- `ipv6`\n- `creditcard`\n- `open` (any one of `(`, `[`, `{`)\n- `close` (`)`, `]`, or `}`)\n\nYou can register your own types and conversions with `register_type(name, regex, converter=str)`.\nAs `qre`\'s goal is not to replicate the functionality of re, this can also act as the "escape hatch"\nwhen you need just a little bit more than what `qre` offers.\n\nHere\'s how to use `register_type` to turn an emoji into a textual description:\n\n```python\nqre.register_type("mood", r"[😀😞]", lambda emoji: {"😀": "good", "😞": "bad"}.get(emoji, "unknown"))\n\nassert qre.search("[mood:mood]", "I\'m feeling 😀 today!") == {"mood": "good" }\n```\n\nNote that `register_type` manipulates a global object, so you only need to register custom types\nonce, probably somewhere towards the start of your program.\n\nPRs for generally useful types are highly welcome.\n\n## Matching functions\n\nMatching functions expect a `pattern` and a `string` to match against. The optional\n`case_sensitive` argument is true by default.\n\n- `match` - Match `pattern` against the whole of the `string`\n- `match_start` - Match `pattern` against the beginning of the `string`\n- `match_end` - Match `pattern` against the end of the `string`\n- `search` - Return the first match of the `pattern` in the `string`\n- `search_all` - Return all matches of the `pattern` in the `string` as a list\n\nAll of the functions always return an object that is either truthy or falsy depending on whether\nthere was a match or not. They never return `None`, and the `unnamed` attribute contains at least an \nempty list, so the returned object is always safe to iterate.\n\nAlternatively, you can use the Matcher object. It has the following useful attributes:\n- `regex` for debugging the generated regex, or for copying it for use with plain `re`\n- `converters` for debugging the converters in use\n\n```python\nmatcher = qre.Matcher("value: [quantitative:float]|[qualitative]", case_sensitive=False)\nassert matcher.match("Value: 1.0") == {"quantitative": 1.0}  # Or any of the other functions above\nassert matcher.regex == "value:\\\\ (?P<quantitative>[+-]?(?:[0-9]*[.])?[0-9]+)|(?P<qualitative>.*)"\nassert matcher.converters == {\'quantitative\': float}\n```\n\nAs a final usage scenario, you can call `qre` on the command line:\n\n```\n$ python qre.py\nusage: qre.py [-h] [--regex] pattern string\n```\n\n## Pattern syntax summary\n\n- Wildcards:\n  - `*` - any character 0+ times\n  - `+` - any 1 character\n  - `?` - any 1 character, maybe\n- Operators:\n  - `|` - either of two characters or groups\n- Groups:\n  - `[name]` - named group called "name", returned in the main dict.\n  - `[]` - unnamed group, returned in the `unnamed` list\n  - `[name:4]`, `[:4]` - group that is 4 characters wide\n  - `[name:int]`, `[:int]` - group that matches the type and is converted to that Python type\n- Escaping:\n  - `[*]`, `[+]`, `[?]`, `[|]` - literal symbol, not wildcard\n  - `[[`, `]]` - literal brackets, not groups\n',
    'author': 'Mikael Honkala',
    'author_email': 'mikael.honkala@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/mikaelho/qre',
    'py_modules': modules,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
